@@ -3,27 +3,15 @@
 
 """This program is self-checking!"""
 
+
 def replace_globals(f, new_globals):
     import sys
 
-
     if sys.version_info.major == 2:
-        args = [
-            f.func_code,
-            new_globals,
-            f.func_name,
-            f.func_defaults,
-            f.func_closure,
-        ]
+        args = [f.func_code, new_globals, f.func_name, f.func_defaults, f.func_closure]
     else:
-        args = [
-            f.__code__,
-            new_globals,
-            f.__name__,
-            f.__defaults__,
-            f.__closure__,
-        ]
-    if hasattr(f, '_vm'):
+        args = [f.__code__, new_globals, f.__name__, f.__defaults__, f.__closure__]
+    if hasattr(f, "_vm"):
         name = args.remove(args[2])
         args.insert(0, name)
         args.append(f._vm)
@@ -39,7 +27,7 @@ def f(NameError=NameError, AssertionError=AssertionError):
     except NameError:
         pass
     else:
-        raise AssertionError('sum in the builtins')
+        raise AssertionError("sum in the builtins")
 
 
 f = replace_globals(f, {})  # no builtins provided
