@@ -1,20 +1,28 @@
 from xpython.interpreter.baseobjspace import W_Root
 from xpython.interpreter.error import OperationError, oefmt
 from xpython.interpreter.pyopcode import SApplicationException
-from xdis import CO_COROUTINE, CO_ITERABLE_COROUTINE, CO_ASYNC_GENERATOR, PYPY_COMPILER_FLAG_NAMES
+from xdis import (
+    CO_COROUTINE,
+    CO_ITERABLE_COROUTINE,
+    CO_ASYNC_GENERATOR,
+    PYPY_COMPILER_FLAG_NAMES,
+)
+
 
 class GeneratorOrCoroutine(W_Root):
-    _immutable_fields_ = ['pycode']
+    _immutable_fields_ = ["pycode"]
 
     def __init__(self, frame, name=None, qualname=None):
         self.space = frame.space
-        self.frame = frame     # turned into None when frame_finished_execution
+        self.frame = frame  # turned into None when frame_finished_execution
         self.pycode = frame.pycode  # usually never None but see __setstate__
         self.running = False
-        self._name = name           # may be null, use get_name()
-        self._qualname = qualname   # may be null, use get_qualname()
-        if (isinstance(self, Coroutine)
-                or self.pycode.co_flags & PYPY_COMPILER_FLAG_NAMES["CO_YIELD_INSIDE_TRY"]):
+        self._name = name  # may be null, use get_name()
+        self._qualname = qualname  # may be null, use get_qualname()
+        if (
+            isinstance(self, Coroutine)
+            or self.pycode.co_flags & PYPY_COMPILER_FLAG_NAMES["CO_YIELD_INSIDE_TRY"]
+        ):
             self.register_finalizer(self.space)
         self.saved_operr = None
 
@@ -35,12 +43,13 @@ class GeneratorOrCoroutine(W_Root):
 
     def descr__repr__(self, space):
         addrstring = self.getaddrstring(space)
-        return space.newtext("<%s object %s at 0x%s>" %
-                          (self.KIND, self.get_qualname(), addrstring))
+        return space.newtext(
+            "<%s object %s at 0x%s>" % (self.KIND, self.get_qualname(), addrstring)
+        )
 
     def descr_send(self, w_arg):
         """send(arg) -> send 'arg' into generator/coroutine,
-return next yielded value or raise StopIteration."""
+        return next yielded value or raise StopIteration."""
         return self.send_ex(w_arg)
 
     def send_error(self, operr):
@@ -79,8 +88,9 @@ return next yielded value or raise StopIteration."""
         if frame.frame_finished_execution:
             self.frame_is_finished()
             if isinstance(self, AsyncGenerator):
-                assert space.is_w(w_result, space.w_None), (
-                    "getting non-None here should be forbidden by the bytecode")
+                assert space.is_w(
+                    w_result, space.w_None
+                ), "getting non-None here should be forbidden by the bytecode"
                 raise OperationError(space.w_StopAsyncIteration, space.w_None)
             else:
                 if space.is_w(w_result, space.w_None):
@@ -88,7 +98,7 @@ return next yielded value or raise StopIteration."""
                 else:
                     raise stopiteration_value(space, w_result)
         else:
-            return w_result     # YIELDed
+            return w_result  # YIELDed
 
     def _invoke_execute_frame(self, w_arg_or_err):
         space = self.space
@@ -99,11 +109,14 @@ return next yielded value or raise StopIteration."""
         # Optimization only: after we've started a Coroutine without
         # CO_YIELD_INSIDE_TRY, then Coroutine._finalize_() will be a no-op
         if frame.last_instr == -1:
-            if (not space.is_w(w_arg_or_err, space.w_None) and
-                not isinstance(w_arg_or_err, SApplicationException)):
-                raise oefmt(space.w_TypeError,
-                            "can't send non-None value to a just-started %s",
-                            self.KIND)
+            if not space.is_w(w_arg_or_err, space.w_None) and not isinstance(
+                w_arg_or_err, SApplicationException
+            ):
+                raise oefmt(
+                    space.w_TypeError,
+                    "can't send non-None value to a just-started %s",
+                    self.KIND,
+                )
         ec = space.getexecutioncontext()
         current_exc_info = ec.sys_exc_info()
         if self.saved_operr is not None:
@@ -117,8 +130,9 @@ return next yielded value or raise StopIteration."""
             try:
                 if e.match(space, space.w_StopIteration):
                     self._leak_stopiteration(e)
-                elif (isinstance(self, AsyncGenerator) and
-                      e.match(space, space.w_StopAsyncIteration)):
+                elif isinstance(self, AsyncGenerator) and e.match(
+                    space, space.w_StopAsyncIteration
+                ):
                     self._leak_stopasynciteration(e)
             finally:
                 self.frame_is_finished()
@@ -152,34 +166,38 @@ return next yielded value or raise StopIteration."""
         # a leaking StopIteration into RuntimeError (with its cause
         # set appropriately).
         space = self.space
-        if (
-            self.pycode.co_flags
-                & (
-                    CO_COROUTINE |
-                    CO_ITERABLE_COROUTINE |
-                    CO_ASYNC_GENERATOR
-                    # | CO_FUTURE_GENERATOR_STOP # after next xdis release
-                )):
-            e2 = OperationError(space.w_RuntimeError,
-                                space.newtext("%s raised StopIteration" %
-                                              self.KIND))
+        if self.pycode.co_flags & (
+            CO_COROUTINE
+            | CO_ITERABLE_COROUTINE
+            | CO_ASYNC_GENERATOR
+            # | CO_FUTURE_GENERATOR_STOP # after next xdis release
+        ):
+            e2 = OperationError(
+                space.w_RuntimeError,
+                space.newtext("%s raised StopIteration" % self.KIND),
+            )
             e2.chain_exceptions_from_cause(space, e)
             raise e2
         else:
-            space.warn(space.newtext("generator '%s' raised StopIteration"
-                                        % self.get_qualname()),
-                       space.w_DeprecationWarning)
+            space.warn(
+                space.newtext(
+                    "generator '%s' raised StopIteration" % self.get_qualname()
+                ),
+                space.w_DeprecationWarning,
+            )
 
     def _leak_stopasynciteration(self, e):
         space = self.space
-        e2 = OperationError(space.w_RuntimeError,
-                   space.newtext("async generator raised StopAsyncIteration"))
+        e2 = OperationError(
+            space.w_RuntimeError,
+            space.newtext("async generator raised StopAsyncIteration"),
+        )
         e2.chain_exceptions_from_cause(space, e)
         raise e2
 
     def descr_throw(self, w_type, w_val=None, w_tb=None):
         """throw(typ[,val[,tb]]) -> raise exception in generator/coroutine,
-return next yielded value or raise StopIteration."""
+        return next yielded value or raise StopIteration."""
         return self.throw(w_type, w_val, w_tb)
 
     def throw(self, w_type, w_val, w_tb):
@@ -199,16 +217,16 @@ return next yielded value or raise StopIteration."""
         operr.normalize_exception(space)
 
         # note: _w_yielded_from is always None if 'self.running'
-        if (self.get_delegate() is not None and
-                    operr.match(space, space.w_GeneratorExit)):
+        if self.get_delegate() is not None and operr.match(
+            space, space.w_GeneratorExit
+        ):
             try:
                 self._gen_close_iter(space)
             except OperationError as e:
                 return self.send_error(e)
 
         if tb is None:
-            tb = space.getattr(operr.get_w_value(space),
-                               space.newtext('__traceback__'))
+            tb = space.getattr(operr.get_w_value(space), space.newtext("__traceback__"))
             if not space.is_w(tb, space.w_None):
                 operr.set_traceback(tb)
         return self.send_error(operr)
@@ -226,7 +244,7 @@ return next yielded value or raise StopIteration."""
     def descr_close(self):
         """close() -> raise GeneratorExit inside generator/coroutine."""
         if self.frame is None:
-            return     # nothing to do in this case
+            return  # nothing to do in this case
         space = self.space
         operr = None
         # note: _w_yielded_from is always None if 'self.running'
@@ -241,13 +259,13 @@ return next yielded value or raise StopIteration."""
         try:
             self.send_error(operr)
         except OperationError as e:
-            if e.match(space, space.w_StopIteration) or \
-                    e.match(space, space.w_GeneratorExit):
+            if e.match(space, space.w_StopIteration) or e.match(
+                space, space.w_GeneratorExit
+            ):
                 return space.w_None
             raise
         else:
-            raise oefmt(space.w_RuntimeError,
-                        "%s ignored GeneratorExit", self.KIND)
+            raise oefmt(space.w_RuntimeError, "%s ignored GeneratorExit", self.KIND)
 
     def descr_gicr_frame(self, space):
         if self.frame is not None and not self.frame.frame_finished_execution:
@@ -262,8 +280,7 @@ return next yielded value or raise StopIteration."""
         if space.isinstance_w(w_name, space.w_unicode):
             self._name = space.text_w(w_name)
         else:
-            raise oefmt(space.w_TypeError,
-                        "__name__ must be set to a string object")
+            raise oefmt(space.w_TypeError, "__name__ must be set to a string object")
 
     def descr__qualname__(self, space):
         return space.newtext(self.get_qualname())
@@ -273,8 +290,9 @@ return next yielded value or raise StopIteration."""
             self._qualname = space.utf8_w(w_name)
         except OperationError as e:
             if e.match(space, space.w_TypeError):
-                raise oefmt(space.w_TypeError,
-                            "__qualname__ must be set to a string object")
+                raise oefmt(
+                    space.w_TypeError, "__qualname__ must be set to a string object"
+                )
             raise
 
     def _finalize_(self):
@@ -315,12 +333,11 @@ class GeneratorIterator(GeneratorOrCoroutine):
     # app-level W_ListObject, which also has an append() method, that's why we
     # generate 2 versions of the function and 2 jit drivers.
     def _create_unpack_into():
-
         def unpack_into(self, results):
             """This is a hack for performance: runs the generator and collects
             all produced items in a list."""
             frame = self.frame
-            if frame is None:    # already finished
+            if frame is None:  # already finished
                 return
             pycode = self.pycode
             while True:
@@ -335,8 +352,10 @@ class GeneratorIterator(GeneratorOrCoroutine):
                 if frame.frame_finished_execution:
                     self.frame_is_finished()
                     break
-                results.append(w_result)     # YIELDed
+                results.append(w_result)  # YIELDed
+
         return unpack_into
+
     unpack_into = _create_unpack_into()
     unpack_into_w = _create_unpack_into()
 
@@ -351,9 +370,11 @@ class Coroutine(GeneratorOrCoroutine):
 
     def _finalize_(self):
         # If coroutine was never awaited on issue a RuntimeWarning.
-        if self.pycode is not None and \
-           self.frame is not None and \
-           self.frame.last_instr == -1:
+        if (
+            self.pycode is not None
+            and self.frame is not None
+            and self.frame.last_instr == -1
+        ):
             space = self.space
             msg = "coroutine '%s' was never awaited" % self.get_qualname()
             space.warn(space.newtext(msg), space.w_RuntimeWarning)
@@ -374,14 +395,17 @@ class CoroutineWrapper(W_Root):
 
     def descr_send(self, space, w_arg):
         return self.coroutine.send_ex(w_arg)
+
     descr_send.__doc__ = Coroutine.descr_send.__doc__
 
     def descr_throw(self, w_type, w_val=None, w_tb=None):
         return self.coroutine.throw(w_type, w_val, w_tb)
+
     descr_throw.__doc__ = Coroutine.descr_throw.__doc__
 
     def descr_close(self):
         return self.coroutine.descr_close()
+
     descr_close.__doc__ = Coroutine.descr_close.__doc__
 
 
@@ -401,12 +425,14 @@ class AIterWrapper(W_Root):
     def descr__next__(self, space):
         raise stopiteration_value(space, self.w_aiter)
 
+
 def stopiteration_value(space, w_value):
     # Mess.  The obvious line, "OperationError(w_StopIteration, w_value)",
     # fails for some types of w_value.  E.g. if it's a subclass of
     # tuple, it will be unpacked as individual arguments.
-    raise OperationError(space.w_StopIteration,
-                         space.call_function(space.w_StopIteration, w_value))
+    raise OperationError(
+        space.w_StopIteration, space.call_function(space.w_StopIteration, w_value)
+    )
 
 
 def gen_close_iter(space, w_yf):
@@ -424,9 +450,13 @@ def gen_close_iter(space, w_yf):
         else:
             space.call_function(w_close)
 
+
 def gen_is_coroutine(w_obj):
-    return (isinstance(w_obj, GeneratorIterator) and
-            (w_obj.pycode.co_flags & CO_ITERABLE_COROUTINE) != 0)
+    return (
+        isinstance(w_obj, GeneratorIterator)
+        and (w_obj.pycode.co_flags & CO_ITERABLE_COROUTINE) != 0
+    )
+
 
 def get_awaitable_iter(space, w_obj):
     # This helper function returns an awaitable for `o`:
@@ -438,18 +468,22 @@ def get_awaitable_iter(space, w_obj):
 
     w_await = space.lookup(w_obj, "__await__")
     if w_await is None:
-        raise oefmt(space.w_TypeError,
-                    "object %T can't be used in 'await' expression",
-                    w_obj)
+        raise oefmt(
+            space.w_TypeError, "object %T can't be used in 'await' expression", w_obj
+        )
     w_res = space.get_and_call_function(w_await, w_obj)
     if isinstance(w_res, Coroutine) or gen_is_coroutine(w_res):
-        raise oefmt(space.w_TypeError,
-                    "__await__() returned a coroutine (it must return an "
-                    "iterator instead, see PEP 492)")
+        raise oefmt(
+            space.w_TypeError,
+            "__await__() returned a coroutine (it must return an "
+            "iterator instead, see PEP 492)",
+        )
     elif space.lookup(w_res, "__next__") is None:
-        raise oefmt(space.w_TypeError,
-                "__await__() returned non-iterator "
-                "of type '%T'", w_res)
+        raise oefmt(
+            space.w_TypeError,
+            "__await__() returned non-iterator " "of type '%T'",
+            w_res,
+        )
     return w_res
 
 
@@ -457,7 +491,8 @@ def get_awaitable_iter(space, w_obj):
 
 
 def get_printable_location_genentry(bytecode):
-    return '%s <generator>' % (bytecode.get_repr(),)
+    return "%s <generator>" % (bytecode.get_repr(),)
+
 
 # ------------------------------------------------
 # Python 3.6 async generators
@@ -546,15 +581,15 @@ class AsyncGenABase(W_Root):
 
     def unwrap_value(self, w_value):
         if isinstance(w_value, AsyncGenValueWrapper):
-            w_value = self.space.call_function(self.space.w_StopIteration,
-                                               w_value.w_value)
+            w_value = self.space.call_function(
+                self.space.w_StopIteration, w_value.w_value
+            )
             raise OperationError(self.space.w_StopIteration, w_value)
         else:
             return w_value
 
 
 class AsyncGenASend(AsyncGenABase):
-
     def __init__(self, async_gen, w_value_to_send):
         AsyncGenABase.__init__(self, async_gen)
         self.w_value_to_send = w_value_to_send
@@ -565,7 +600,7 @@ class AsyncGenASend(AsyncGenABase):
             raise OperationError(space.w_StopIteration, space.w_None)
 
         # We think that the code should look like this:
-        #if self.w_value_to_send is not None:
+        # if self.w_value_to_send is not None:
         #    if not space.is_w(w_arg_or_err, space.w_None):
         #        raise ...
         #    w_arg_or_err = self.w_value_to_send
@@ -598,7 +633,6 @@ class AsyncGenASend(AsyncGenABase):
 
 
 class AsyncGenAThrow(AsyncGenABase):
-
     def __init__(self, async_gen, w_exc_type, w_exc_value, w_exc_tb):
         AsyncGenABase.__init__(self, async_gen)
         self.w_exc_type = w_exc_type
@@ -613,8 +647,12 @@ class AsyncGenAThrow(AsyncGenABase):
 
         if self.state == self.ST_INIT:
             if not space.is_w(w_arg_or_err, space.w_None):
-                raise OperationError(space.w_RuntimeError, space.newtext(
-                    "can't send non-None value to a just-started coroutine"))
+                raise OperationError(
+                    space.w_RuntimeError,
+                    space.newtext(
+                        "can't send non-None value to a just-started coroutine"
+                    ),
+                )
             self.state = self.ST_ITER
             throwing = True
         else:
@@ -624,19 +662,22 @@ class AsyncGenAThrow(AsyncGenABase):
             if throwing:
                 if self.w_exc_type is None:
                     # TODO: add equivalent to CPython's o->agt_gen->ag_closed = 1;
-                    w_value = self.async_gen.throw(space.w_GeneratorExit,
-                                                   None, None)
+                    w_value = self.async_gen.throw(space.w_GeneratorExit, None, None)
                 else:
-                    w_value = self.async_gen.throw(self.w_exc_type,
-                                                   self.w_exc_value,
-                                                   self.w_exc_tb)
+                    w_value = self.async_gen.throw(
+                        self.w_exc_type, self.w_exc_value, self.w_exc_tb
+                    )
             else:
                 w_value = self.async_gen.send_ex(w_arg_or_err)
 
-            if (self.w_exc_type is None and w_value is not None and
-                    isinstance(w_value, AsyncGenValueWrapper)):
-                raise oefmt(space.w_RuntimeError,
-                            "async generator ignored GeneratorExit")
+            if (
+                self.w_exc_type is None
+                and w_value is not None
+                and isinstance(w_value, AsyncGenValueWrapper)
+            ):
+                raise oefmt(
+                    space.w_RuntimeError, "async generator ignored GeneratorExit"
+                )
             return self.unwrap_value(w_value)
         except OperationError as e:
             self.handle_error(e)
@@ -644,8 +685,10 @@ class AsyncGenAThrow(AsyncGenABase):
     def do_throw(self, w_type, w_val, w_tb):
         space = self.space
         if self.state == self.ST_INIT:
-            raise OperationError(self.space.w_RuntimeError,
-                space.newtext("can't do async_generator.athrow().throw()"))
+            raise OperationError(
+                self.space.w_RuntimeError,
+                space.newtext("can't do async_generator.athrow().throw()"),
+            )
         if self.state == self.ST_CLOSED:
             raise OperationError(space.w_StopIteration, space.w_None)
         try:
@@ -657,8 +700,9 @@ class AsyncGenAThrow(AsyncGenABase):
     def handle_error(self, e):
         space = self.space
         self.state = self.ST_CLOSED
-        if (e.match(space, space.w_StopAsyncIteration) or
-                    e.match(space, space.w_StopIteration)):
+        if e.match(space, space.w_StopAsyncIteration) or e.match(
+            space, space.w_StopIteration
+        ):
             if self.w_exc_type is None:
                 # When aclose() is called we don't want to propagate
                 # StopAsyncIteration or GeneratorExit; just raise
