@@ -57,6 +57,33 @@ class PyVMRuntimeError(Exception):
 class PyVMUncaughtException(Exception):
     """Uncaught RuntimeError in operation of PyVM."""
 
+    def __init__(self, name, args, traceback=None):
+        self.__name__ = name
+        self.traceback = traceback
+        self.args = args
+
+    def __getattr__(self, name):
+        if name == "__traceback__":
+            return self.traceback
+        else:
+            return super().__getattr__(name)
+
+    def __getitem__(self, i):
+        assert 0 <= i <= 2, "Exception index should be in range 0..2 was %d" % i
+        if i == 0:
+            return self.__name__
+        elif i == 1:
+            return self.args
+        else:
+            return self.traceback
+
+    @classmethod
+    def from_tuple(cls, exception):
+        assert (
+            len(exception) == 3
+        ), "Expecting exception tuple to have 3 args: type, args, traceback"
+        return cls(*exception)
+
     pass
 
 
@@ -100,7 +127,7 @@ def format_instruction(
         if line_number is None
         else LINE_NUMBER_WIDTH_FMT % line_number
     )
-    mess = "%s%3d: %s%s %s" % (line_str, offset, byte_name, stack_args, argrepr,)
+    mess = "%s%3d: %s%s %s" % (line_str, offset, byte_name, stack_args, argrepr)
     if extra_debug and frame:
         mess += " %s in %s:%s" % (code.co_name, code.co_filename, frame.f_lineno)
     return mess
@@ -140,7 +167,7 @@ class PyVM(object):
 
         self.in_exception_processing = False
 
-        # This is somewhat hoaky:
+        # This is somewhat hokey:
         # Give byteop routines a way to raise an error, without having
         # to import this file. We import from from byteops.
         # Alternatively, VMError could be
@@ -156,9 +183,17 @@ class PyVM(object):
     ##############################################
     # Frame operations. First the frame stack....
     ##############################################
-    def top(self):
-        """Return the value at the top of the stack, with no changes."""
-        return self.frame.stack[-1]
+    def access(self, i=0):
+        """return object at position i.
+        Default to the top of the stack, but `i` can be a count from the top
+        instead.
+        """
+        return self.frame.stack[-1 - i]
+
+    def peek(self, n):
+        if n <= 0:
+            raise PyVMError("Peek value must be greater than 0")
+        return self.frame.stack[-n]
 
     def pop(self, i=0):
         """Pop a value from the stack.
@@ -169,10 +204,6 @@ class PyVM(object):
         """
         return self.frame.stack.pop(-1 - i)
 
-    def push(self, *vals):
-        """Push values onto the value stack."""
-        self.frame.stack.extend(vals)
-
     def popn(self, n):
         """Pop a number of values from the value stack.
 
@@ -186,21 +217,25 @@ class PyVM(object):
         else:
             return []
 
-    def peek(self, n):
-        """Get a value `n` entries down in the stack, without changing the stack."""
-        return self.frame.stack[-n]
+    def push(self, *vals):
+        """Push values onto the value stack."""
+        self.frame.stack.extend(vals)
+
+    def top(self):
+        """Return the value at the top of the stack, with no changes."""
+        return self.frame.stack[-1]
 
     # end of frame stack operations
     # onto frame block operations..
 
+    def pop_block(self):
+        return self.frame.block_stack.pop()
+
     def push_block(self, type, handler=None, level=None):
         if level is None:
             level = len(self.frame.stack)
         self.frame.block_stack.append(Block(type, handler, level))
 
-    def pop_block(self):
-        return self.frame.block_stack.pop()
-
     def top_block(self):
         return self.frame.block_stack[-1]
 
@@ -328,13 +363,12 @@ class PyVM(object):
             if self.last_traceback:
                 self.last_traceback.print_tb()
                 print("%s" % self.last_exception[0].__name__, end="")
-                tail = (
-                    (": %s" % "\n".join(self.last_exception[1].args))
-                    if self.last_exception[1].args
-                    else ""
-                )
+                le1 = self.last_exception[1]
+                tail = ""
+                if le1:
+                    tail = "\n".join(le1.args)
                 print(tail)
-            raise PyVMUncaughtException
+            raise
 
         # Frame ran to normal completion... check some invariants
         if toplevel:
@@ -359,7 +393,7 @@ class PyVM(object):
             self.last_exception = exctype, value, tb
 
     def parse_byte_and_args(self, byte_code, replay=False):
-        """ Parse 1 - 3 bytes of bytecode into
+        """Parse 1 - 3 bytes of bytecode into
         an instruction and optionally arguments.
 
         Argument replay is used to handle breakpoints.
@@ -447,7 +481,7 @@ class PyVM(object):
         return byte_name, byte_code, int_arg, arguments, offset, line_number
 
     def log(self, byte_name, int_arg, arguments, offset, line_number):
-        """ Log arguments, block stack, and data stack for each opcode."""
+        """Log arguments, block stack, and data stack for each opcode."""
         op = self.format_instruction(
             self.frame,
             self.opc,
@@ -468,7 +502,7 @@ class PyVM(object):
         log.info("%s%s" % (indent, op))
 
     def dispatch(self, byte_name, int_arg, arguments, offset, line_number):
-        """ Dispatch by byte_name to the corresponding methods.
+        """Dispatch by byte_name to the corresponding methods.
         Exceptions are caught and set on the virtual machine."""
 
         why = None
@@ -538,7 +572,7 @@ class PyVM(object):
         return why
 
     def manage_block_stack(self, why):
-        """ Manage a frame's block stack.
+        """Manage a frame's block stack.
         Manipulate the block stack and data stack for looping,
         exception handling, or returning."""
         assert why != "yield"
@@ -599,6 +633,9 @@ class PyVM(object):
                 # 3.5+ WITH_CLEANUP_FINISH
                 # Nothing needs to be done here.
                 return None
+            elif why == "return":
+                # 3.8+ END_FINALLY
+                pass
 
         return why
 
@@ -687,7 +724,11 @@ class PyVM(object):
             if last_exception and last_exception[0]:
                 if isinstance(last_exception[2], Traceback):
                     if not self.frame:
-                        raise PyVMUncaughtException(last_exception)
+                        if isinstance(last_exception, tuple):
+                            self.last_exception = PyVMUncaughtException.from_tuple(
+                                last_exception
+                            )
+                        raise self.last_exception
                 else:
                     six.reraise(*self.last_exception)
             else:
